@@ -12,7 +12,7 @@ import urllib
 import urllib2
 import re
 
-__version__  = '0.10.7'
+__version__  = '0.10.8'
 __author__ = "Hiroki Ohtani (liris.pp [at] gmail.com)"
 __copyright__ = "Copyright (c) 2006 Hiroki Ohtani"
 __license__ = "LGPL"
@@ -400,7 +400,7 @@ class Transport(object):
 
         url = self.url + "/" + command
         headers = headers.copy()
-        if not headers.has_key("Content-Type") and autoContentType:
+        if "Content-Type" not in headers and autoContentType:
             headers["Content-Type"] = "application/x-www-form-urlencoded"
         if self.auth:
             encodedAuth = base64.encodestring(self.auth).replace("\n", "")
@@ -807,7 +807,7 @@ class Node(object):
         def get(result):
             return self.admins
 
-        if self.admins < 0:
+        if self.admins != None:
             return self._set_info(get)
         return self.transport.extract(get)
 
@@ -820,7 +820,7 @@ class Node(object):
         def get(result):
             return self.users
 
-        if self.users < 0:
+        if self.users != None:
             return self._set_info(get)
         return self.transport.extract(get)
 
@@ -835,7 +835,7 @@ class Node(object):
         def get(result):
             return self.links
 
-        if self.links < 0:
+        if self.links != None:
             return self._set_info(get)
         return self.transport.extract(get)
 
@@ -863,7 +863,6 @@ class Node(object):
                     hints[elems[0]] = elems[1]
                     if 'HIT' == elems[0]:
                         ehits = int(elems[1])
-
             for section in sections[1:]:
                 lines = [line.strip() for line in section.splitlines()]
                 if len(lines) < 4:
@@ -895,9 +894,7 @@ class Node(object):
                 if rduri:
                     rdoc = ResultDocument(rduri, rdattrs, rdsnippet, rdvector)
                     docs.append(rdoc)
-
-            if len(docs) != ehits:
-                return None
+                    
             return nres
 
         def err(resutl):
